package net.wanji.web.dto;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * 运行计划DTO
 *
 * @author Kent HAN
 * @date 2023/1/28 16:11
 */
@NoArgsConstructor
@Data
public class RunningPlanDTO {
    @ApiModelProperty(value = "路口ID", required = true)
    private String crossId;
    @ApiModelProperty(value = "日计划列表", required = true)
    private List<DailyPlanListElement> dailyPlanList;
    @ApiModelProperty(value = "运行计划列表", required = true)
    private List<SchedulesPlanListElement> schedulesPlanList;

    @NoArgsConstructor
    @Data
    public static class DailyPlanListElement {
        @ApiModelProperty(value = "计划编号", required = true)
        private String planNo;
        @ApiModelProperty(value = "日计划名", required = true)
        private String name;
        @ApiModelProperty(value = "开始时间结束时间列表", required = true)
        private List<TimeListElement> timeList;
    }
    @NoArgsConstructor
    @Data
    public static class TimeListElement {
        @ApiModelProperty(value = "开始时间", required = true)
        private String startTime;
        @ApiModelProperty(value = "结束时间", required = true)
        private String endTime;
        @ApiModelProperty(value = "方案名", required = true)
        private String schemeName;
    }

    @NoArgsConstructor
    @Data
    public static class SchedulesPlanListElement {
        @ApiModelProperty(value = "运行计划ID", required = true)
        private Integer id;
        @ApiModelProperty(value = "运行计划编号", required = true)
        private String scheduleNo;
        @ApiModelProperty(value = "运行计划名", required = true)
        private String name;
        @ApiModelProperty(value = "执行的日计划列表", required = true)
        private List<ExecListElement> execList;
    }

    @NoArgsConstructor
    @Data
    public static class ExecListElement {
        @ApiModelProperty(value = "星期：1周一，2周二，3周三，4周四，5周五，6周六，7周日", required = true)
        private List<Integer> week;
        @ApiModelProperty(value = "特殊日期列表，格式 2023-01-28", required = true)
        private List<String> specialDateList;
        @ApiModelProperty(value = "执行日计划名", required = true)
        private String planName;
    }
}
