package net.wanji.web.dto;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/1/5 10:30
 */
@NoArgsConstructor
@Data
public class SaveSchemeConfigDTO {
    @ApiModelProperty(value = "路口ID", required = true)
    private String crossId;
    @ApiModelProperty(value = "配时方式 1阶段式 2环式", required = true)
    private Integer timeType;
    private List<PhaseScheme> phaseSchemeList; // 方案列表
    @Data
    public static class PhaseScheme {
        @ApiModelProperty(value = "方案号", required = true)
        private String schemeNo;
        @ApiModelProperty(value = "方案名称", required = true)
        private String name;
        @ApiModelProperty(value = "协调相位号", required = false)
        private String coordPhaseNo = "";
        @ApiModelProperty(value = "周期", required = true)
        private Integer cycle = 0;
        @ApiModelProperty(value = "相位差", required = false)
        private Integer offset = 0;
        private List<RingListElement> ringList; // 环列表
        private List<PhaseListElement> specialControlModeList; // 特殊控制相位列表

    }

    @Data
    public static class RingListElement {
        @ApiModelProperty(value = "环号", required = true)
        private Integer ringNo;
        List<GroupListElement> groupList; // 组列表

    }

    @Data
    public static class GroupListElement {
        @ApiModelProperty(value = "组号", required = true)
        private Integer groupNo;
        List<PhaseListElement> phaseList; // 相位列表
    }

    @Data
    public static class PhaseListElement {
        @ApiModelProperty(value = "相位号", required = true)
        private String phaseNo;
        @ApiModelProperty(value = "相位类型 1实相位 2虚相位 3伴随相位", required = true)
        private Integer phaseType;
        @ApiModelProperty(value = "最小绿灯时间", required = true)
        private Integer minGreenTime = 0;
        @ApiModelProperty(value = "最大绿灯时间", required = true)
        private Integer maxGreenTime = 0;
        @ApiModelProperty(value = "绿灯时间", required = true)
        private Integer greenTime = 0;
        @ApiModelProperty(value = "绿闪时间", required = true)
        private Integer greenFlashTime = 0;
        @ApiModelProperty(value = "黄闪时间", required = true)
        private Integer yellowFlashTime = 0;
        @ApiModelProperty(value = "红闪时间", required = true)
        private Integer redFlashTime = 0;
        @ApiModelProperty(value = "黄灯时间", required = true)
        private Integer yellowTime = 0;
        @ApiModelProperty(value = "红灯时间", required = true)
        private Integer redTime = 0;
        @ApiModelProperty(value = "是否黄闪 0否 1是", required = true)
        private Integer yellowFlash = 0;
        @ApiModelProperty(value = "是否红灯 0否 1是", required = true)
        private Integer isRed = 0;
        @ApiModelProperty(value = "是否绿灯 0否 1是", required = true)
        private Integer isGreen = 0;
        @ApiModelProperty(value = "是否绿闪 0否 1是", required = true)
        private Integer greenFlash = 0;
        @ApiModelProperty(value = "母相位号列表", required = true)
        List<String> accompanyPhaseNoList;
        private List<DirListElement> dirList; // 方向列表
    }

    @Data
    public static class DirListElement {
        @ApiModelProperty(value = "车道进口方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北", required = true)
        private Integer dir;
        @ApiModelProperty(value = "是否有行人相位：0否；1是", required = true)
        private Integer hasPersonPhase = 0;
        private List<LaneListElement> laneList; // 车道列表
    }

    @Data
    public static class LaneListElement {
        @ApiModelProperty(value = "车道转向：0无方向 箭头 1:直行2:左转,3:右转,4:掉头,5：左直,6:右直,7:左转掉头,8:左直掉头, 9:左直右, 10:左右转", required = true)
        private Integer direction;
        @ApiModelProperty(value = "车道类别：1机动车；2非机动车；3公交专用；4可变；5潮汐", required = true)
        private Integer laneType;
    }
}